"""
The qiprofile-rest unit tests.

:Note: unlike the other OHSU QIN python projects, the qiprofile-rest
  tests are contained within the main qiprofile-rest package. The test
  module is thus contained in the qiprofile-rest source distribution.
  This allows other python projects to call the qiprofile-rest seed
  module to populate a test or demo database.
"""
